summaryrefslogtreecommitdiff
path: root/src/driver
diff options
context:
space:
mode:
authormidipix <writeonce@midipix.org>2024-02-13 03:10:11 +0000
committermidipix <writeonce@midipix.org>2024-02-13 03:13:49 +0000
commitc578162753123ea7d2746d2032ceb439c7c31d32 (patch)
tree686bee282ea50e6eb7854259a2e02ef350b26997 /src/driver
parent32c2302764dce9380c427b748bc634825d08a2f7 (diff)
downloadslibtool-c578162753123ea7d2746d2032ceb439c7c31d32.tar.bz2
slibtool-c578162753123ea7d2746d2032ceb439c7c31d32.tar.xz
driver: rename --config as --info in anticipation of a compatible --config.
Diffstat (limited to 'src/driver')
-rw-r--r--src/driver/slbt_amain.c4
-rw-r--r--src/driver/slbt_driver_ctx.c6
-rw-r--r--src/driver/slbt_split_argv.c12
3 files changed, 11 insertions, 11 deletions
diff --git a/src/driver/slbt_amain.c b/src/driver/slbt_amain.c
index d89884d..0136625 100644
--- a/src/driver/slbt_amain.c
+++ b/src/driver/slbt_amain.c
@@ -59,8 +59,8 @@ static ssize_t slbt_version(struct slbt_driver_ctx * dctx, int fdout)
static void slbt_perform_driver_actions(struct slbt_driver_ctx * dctx)
{
- if (dctx->cctx->drvflags & SLBT_DRIVER_CONFIG)
- slbt_output_config(dctx);
+ if (dctx->cctx->drvflags & SLBT_DRIVER_INFO)
+ slbt_output_info(dctx);
if (dctx->cctx->drvflags & SLBT_DRIVER_FEATURES)
slbt_output_features(dctx);
diff --git a/src/driver/slbt_driver_ctx.c b/src/driver/slbt_driver_ctx.c
index c2ff1d0..d03d1ed 100644
--- a/src/driver/slbt_driver_ctx.c
+++ b/src/driver/slbt_driver_ctx.c
@@ -488,8 +488,8 @@ int slbt_get_driver_ctx(
cmdnoshared = entry;
break;
- case TAG_CONFIG:
- cctx.drvflags |= SLBT_DRIVER_CONFIG;
+ case TAG_INFO:
+ cctx.drvflags |= SLBT_DRIVER_INFO;
break;
case TAG_DUMPMACHINE:
@@ -773,7 +773,7 @@ int slbt_get_driver_ctx(
}
/* info mode */
- if (cctx.drvflags & (SLBT_DRIVER_CONFIG | SLBT_DRIVER_FEATURES))
+ if (cctx.drvflags & (SLBT_DRIVER_INFO | SLBT_DRIVER_FEATURES))
cctx.mode = SLBT_MODE_INFO;
/* --tag */
diff --git a/src/driver/slbt_split_argv.c b/src/driver/slbt_split_argv.c
index 2ad62ca..946468e 100644
--- a/src/driver/slbt_split_argv.c
+++ b/src/driver/slbt_split_argv.c
@@ -51,7 +51,7 @@ int slbt_split_argv(
struct argv_entry * mode;
struct argv_entry * help;
struct argv_entry * version;
- struct argv_entry * config;
+ struct argv_entry * info;
struct argv_entry * finish;
struct argv_entry * features;
struct argv_entry * ccwrap;
@@ -117,8 +117,8 @@ int slbt_split_argv(
return -1;
}
- /* missing all of --mode, --help, --version, --config, --dumpmachine, --features, and --finish? */
- mode = help = version = config = finish = features = ccwrap = dumpmachine = aropt = 0;
+ /* missing all of --mode, --help, --version, --info, --dumpmachine, --features, and --finish? */
+ mode = help = version = info = finish = features = ccwrap = dumpmachine = aropt = 0;
for (entry=meta->entries; entry->fopt; entry++)
if (entry->tag == TAG_MODE)
@@ -127,8 +127,8 @@ int slbt_split_argv(
help = entry;
else if (entry->tag == TAG_VERSION)
version = entry;
- else if (entry->tag == TAG_CONFIG)
- config = entry;
+ else if (entry->tag == TAG_INFO)
+ info = entry;
else if (entry->tag == TAG_FINISH)
finish = entry;
else if (entry->tag == TAG_FEATURES)
@@ -155,7 +155,7 @@ int slbt_split_argv(
return -1;
}
- if (!mode && !help && !version && !config && !finish && !features && !dumpmachine && !altmode) {
+ if (!mode && !help && !version && !info && !finish && !features && !dumpmachine && !altmode) {
slbt_dprintf(fderr,
"%s: error: --mode must be specified.\n",
program);